### Name: igDirect
### Title: Provide an Initial Guess For the Experiment-Specific Parameters
###   of a Direct Fit
### Aliases: igDirect


### ** Examples

## Parameters of the monoexponential calcium transient
tOn  <- 1
Time <- seq(0,12,length.out=160)
Ca0  <- 0.10
dCa  <- 0.25
tau  <- 1.5

## Create a monoexponential calcium decay
Ca <- caMonoExp(t = Time, tOn = tOn,
                Ca0 = Ca0, dCa = dCa, tau = tau)

## Calibrated parameters
R_min <- list(value=0.136, mean=0.136, se=0.00363, USE_se=TRUE)
R_max <- list(value=2.701, mean=2.701, se=0.151,   USE_se=TRUE)
K_eff <- list(value=3.637, mean=3.637, se=0.729,   USE_se=TRUE)
K_d   <- list(value=0.583, mean=0.583, se=0.123,   USE_se=TRUE)

## Experiment-specific parameters
nb_B    <- 1
B_T     <- 100.0
T_340   <- 0.015
T_380   <- 0.006
P       <- 200
P_B     <- 200
phi     <- 2
S_B_340 <- 30
S_B_380 <- 80

## Define Background and Transient fluorescence
## signals at 340 and 380 nm
adu_B_340 <- fluo(Ca=rep(0,nb_B),
                  R_min=R_min$value, R_max=R_max$value,
                  K_eff=K_eff$value, K_d=K_d$value,
                  B_T=0, phi=phi, S_B=S_B_340,
                  T_stim=T_340, P=P, P_B=P_B)

adu_340   <- fluo(Ca=Ca,
                  R_min=R_min$value, R_max=R_max$value,
                  K_eff=K_eff$value, K_d=K_d$value,
                  B_T=B_T, phi=phi, S_B=S_B_340,
                  T_stim=T_340, P=P, P_B=P_B)
  
adu_B_380 <- fluo(Ca=rep(0,nb_B),
                  R_min=1, R_max=1,
                  K_eff=K_eff$value, K_d=K_d$value,
                  B_T=0, phi=phi, S_B=S_B_380,
                  T_stim=T_380, P=P, P_B=P_B)

adu_380   <- fluo(Ca=Ca,
                  R_min=1, R_max=1,
                  K_eff=K_eff$value, K_d=K_d$value,
                  B_T=B_T, phi=phi, S_B=S_B_380,
                  T_stim=T_380, P=P, P_B=P_B)

## Add Poissonian noise to these signals
adu_B_340 <- rpois(length(adu_B_340), adu_B_340)
adu_340   <- rpois(length(adu_340), adu_340)
adu_B_380 <- rpois(length(adu_B_380), adu_B_380)
adu_380   <- rpois(length(adu_380), adu_380)

## Extract the noisy calcium transient
## (from the ratiometric transformation)
Ca_noisy <- caFromRatio(adu_B_340, adu_340,
                        adu_B_380, adu_380,
                        T_340, T_380,
                        P, P_B,
                        R_min, R_max, K_eff,
                        Plot = FALSE)

## Perform a ratiometric fit to determine
## the calcium dynamics parameters
ratio_fit <- ratioFitFromCa(Ca_noisy, t=Time, tOn, type="mono")

## List the fitted parameters and create
## the corresponding calcium transient
ig_mono <- as.list(ratio_fit$par)
names(ig_mono) <- c("log_Ca0","log_dCa","log_tau")
class(ig_mono) <- "initial_guess"

## Perform an Initial Guess for the Experiment-Specific Parameters
ig_direct <- igDirect(adu_B_340 = adu_B_340,
                      adu_340 = adu_340,
                      adu_B_380 = adu_B_380,
                      adu_380 = adu_380,
                      ig_ratio = ig_mono,
                      t = Time, tOn = tOn, subset = 1:length(Time),
                      R_min = R_min$value, R_max = R_max$value,
                      K_eff = K_eff$value, K_d = K_d$value,
                      B_T = 100, T_340 = T_340, T_380 = T_380, P = P, P_B = P_B)

## Compare the initial guess with the known values of the parameters
print(exp(as.vector(unlist(ig_direct))))
print(c(Ca0, dCa, tau, phi, S_B_340, S_B_380))



